@@ -1,6 +1,6 @@
-from sqlee.sqlee import SqleeRepository
-from sqlee.config import __version__
-from sqlee.utils.exceptions import VersionError
+from .sqlee import SqleeRepository
+from .config import __version__
+from .utils.exceptions import VersionError
 
 __name__ = "sqlee"
 __version__ = __version__
