@@ -114,10 +114,11 @@ class SqleeRepository:
         tables = self.all_tables
         create_table = self.create_table
         create = self.create_table
-        exit = lambda: os._exit(0)
         while True:
             try:
                 cmd = prompt('SQLEE>>> ')
+                if cmd.replace(" ", "") == "exit()":
+                    return
             except NoConsoleScreenBufferError:
                 if Windows:
                     print("SQLEE CONSOLE必须在 'cmd.exe' 中运行 !")
